@@ -24,7 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <string.h>
 #include <stdlib.h>
@@ -69,6 +69,7 @@ static const GDebugKey gdk_debug_keys[] = {
   {"input",	    GDK_DEBUG_INPUT},
   {"cursor",	    GDK_DEBUG_CURSOR},
   {"multihead",	    GDK_DEBUG_MULTIHEAD},
+  {"xinerama",	    GDK_DEBUG_XINERAMA}
 };
 
 static const int gdk_ndebug_keys = G_N_ELEMENTS (gdk_debug_keys);
@@ -103,14 +104,13 @@ gdk_arg_context_parse (GdkArgContext *context, gint *argc, gchar ***argv)
 {
   int i, j, k;
 
-  /* Save a copy of the original argc and argv */
   if (argc && argv)
     {
       for (i = 1; i < *argc; i++)
 	{
 	  char *arg;
 	  
-	  if (!(*argv)[i][0] == '-' && (*argv)[i][1] == '-')
+	  if (!((*argv)[i][0] == '-' && (*argv)[i][1] == '-'))
 	    continue;
 	  
 	  arg = (*argv)[i] + 2;
@@ -294,6 +294,7 @@ gdk_parse_args (int    *argc,
 
   gdk_initialized = TRUE;
 
+  /* Save a copy of the original argc and argv */
   if (argc && argv)
     {
       gdk_argc = *argc;
@@ -302,17 +303,17 @@ gdk_parse_args (int    *argc,
       for (i = 0; i < gdk_argc; i++)
 	gdk_argv[i] = g_strdup ((*argv)[i]);
       gdk_argv[gdk_argc] = NULL;
+    }
 
-      if (*argc > 0)
-	{
-	  gchar *d;
-	  
-	  d = strrchr((*argv)[0], G_DIR_SEPARATOR);
-	  if (d != NULL)
-	    g_set_prgname (d + 1);
-	  else
-	    g_set_prgname ((*argv)[0]);
-	}
+  if (argc && argv && *argc > 0)
+    {
+      gchar *d;
+      
+      d = strrchr((*argv)[0], G_DIR_SEPARATOR);
+      if (d != NULL)
+	g_set_prgname (d + 1);
+      else
+	g_set_prgname ((*argv)[0]);
     }
   else
     {
@@ -494,6 +495,20 @@ gdk_threads_leave ()
   GDK_THREADS_LEAVE ();
 }
 
+static void
+gdk_threads_impl_lock (void)
+{
+  if (gdk_threads_mutex)
+    g_mutex_lock (gdk_threads_mutex);
+}
+
+static void
+gdk_threads_impl_unlock (void)
+{
+  if (gdk_threads_mutex)
+    g_mutex_unlock (gdk_threads_mutex);
+}
+
 /**
  * gdk_threads_init:
  * 
@@ -511,6 +526,50 @@ gdk_threads_init ()
     g_error ("g_thread_init() must be called before gdk_threads_init()");
 
   gdk_threads_mutex = g_mutex_new ();
+  if (!gdk_threads_lock)
+    gdk_threads_lock = gdk_threads_impl_lock;
+  if (!gdk_threads_unlock)
+    gdk_threads_unlock = gdk_threads_impl_unlock;
+}
+
+/**
+ * gdk_threads_set_lock_functions:
+ * @enter_fn:   function called to guard GDK
+ * @leave_fn: function called to release the guard
+ *
+ * Allows the application to replace the standard method that
+ * GDK uses to protect its data structures. Normally, GDK
+ * creates a single #GMutex that is locked by gdk_threads_enter(),
+ * and released by gdk_threads_leave(); using this function an
+ * application provides, instead, a function @enter_fn that is
+ * called by gdk_threads_enter() and a function @leave_fn that is
+ * called by gdk_threads_leave().
+ *
+ * The functions must provide at least same locking functionality
+ * as the default implementation, but can also do extra application
+ * specific processing.
+ *
+ * As an example, consider an application that has its own recursive
+ * lock that when held, holds the GTK+ lock as well. When GTK+ unlocks
+ * the GTK+ lock when entering a recursive main loop, the application
+ * must temporarily release its lock as well.
+ *
+ * Most threaded GTK+ apps won't need to use this method.
+ *
+ * This method must be called before gdk_threads_init(), and cannot
+ * be called multiple times.
+ *
+ * Since: 2.4
+ **/
+void
+gdk_threads_set_lock_functions (GCallback enter_fn,
+				GCallback leave_fn)
+{
+  g_return_if_fail (gdk_threads_lock == NULL &&
+		    gdk_threads_unlock == NULL);
+
+  gdk_threads_lock = enter_fn;
+  gdk_threads_unlock = leave_fn;
 }
 
 G_CONST_RETURN char *
