@@ -24,6 +24,8 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
+
 #include "gdkconfig.h"
 
 #include <locale.h>
@@ -48,7 +50,6 @@
 
 #include <pango/pango-utils.h>	/* For pango_split_file_list */
 
-#include "config.h"
 #include "gtkintl.h"
 
 #include "gtkaccelmap.h"
@@ -2331,8 +2332,17 @@ gtk_propagate_event (GtkWidget *widget,
       while (TRUE)
 	{
 	  GtkWidget *tmp;
-	  
-	  handled_event = !GTK_WIDGET_IS_SENSITIVE (widget) || gtk_widget_event (widget, event);
+
+	  /* Scroll events are special cased here because it
+	   * feels wrong when scrolling a GtkViewport, say,
+	   * to have children of the viewport eat the scroll
+	   * event
+	   */
+	  if (!GTK_WIDGET_IS_SENSITIVE (widget))
+	    handled_event = event->type != GDK_SCROLL;
+	  else
+	    handled_event = gtk_widget_event (widget, event);
+	      
 	  tmp = widget->parent;
 	  g_object_unref (widget);
 
