@@ -20,7 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <config.h>
 #include "gtktoolbutton.h"
 #include "gtkbutton.h"
 #include "gtkhbox.h"
@@ -32,9 +32,7 @@
 #include "gtkvbox.h"
 #include "gtkintl.h"
 #include "gtktoolbar.h"
-#include "gtkactivatable.h"
-#include "gtkprivate.h"
-#include "gtkalias.h"
+#include "gtkiconfactory.h"
 
 #include <string.h>
 
@@ -51,8 +49,7 @@ enum {
   PROP_USE_UNDERLINE,
   PROP_LABEL_WIDGET,
   PROP_STOCK_ID,
-  PROP_ICON_NAME,
-  PROP_ICON_WIDGET
+  PROP_ICON_WIDGET,
 };
 
 static void gtk_tool_button_init          (GtkToolButton      *button,
@@ -74,65 +71,49 @@ static void gtk_tool_button_toolbar_reconfigured (GtkToolItem *tool_item);
 static gboolean   gtk_tool_button_create_menu_proxy (GtkToolItem     *item);
 static void       button_clicked                    (GtkWidget       *widget,
 						     GtkToolButton   *button);
-static void gtk_tool_button_style_set      (GtkWidget          *widget,
-					    GtkStyle           *prev_style);
 
 static void gtk_tool_button_construct_contents (GtkToolItem *tool_item);
+      
+static GObjectClass *parent_class = NULL;
+static guint         toolbutton_signals[LAST_SIGNAL] = { 0 };
 
-static void gtk_tool_button_activatable_interface_init (GtkActivatableIface  *iface);
-static void gtk_tool_button_update                     (GtkActivatable       *activatable,
-							GtkAction            *action,
-							const gchar          *property_name);
-static void gtk_tool_button_sync_action_properties     (GtkActivatable       *activatable,
-							GtkAction            *action);
-
+#define GTK_TOOL_BUTTON_GET_PRIVATE(obj)(G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_TYPE_TOOL_BUTTON, GtkToolButtonPrivate))
 
 struct _GtkToolButtonPrivate
 {
   GtkWidget *button;
 
   gchar *stock_id;
-  gchar *icon_name;
   gchar *label_text;
   GtkWidget *label_widget;
   GtkWidget *icon_widget;
-
-  GtkSizeGroup *text_size_group;
-
+  
   guint use_underline : 1;
-  guint contents_invalid : 1;
 };
 
-static GObjectClass        *parent_class = NULL;
-static GtkActivatableIface *parent_activatable_iface;
-static guint                toolbutton_signals[LAST_SIGNAL] = { 0 };
-
-#define GTK_TOOL_BUTTON_GET_PRIVATE(obj)(G_TYPE_INSTANCE_GET_PRIVATE ((obj), GTK_TYPE_TOOL_BUTTON, GtkToolButtonPrivate))
-
 GType
 gtk_tool_button_get_type (void)
 {
-  static GType type = 0;
-  
+  static GtkType type = 0;
+
   if (!type)
     {
-      const GInterfaceInfo activatable_info =
-      {
-        (GInterfaceInitFunc) gtk_tool_button_activatable_interface_init,
-        (GInterfaceFinalizeFunc) NULL,
-        NULL
-      };
+      static const GTypeInfo type_info =
+	{
+	  sizeof (GtkToolButtonClass),
+	  (GBaseInitFunc) NULL,
+	  (GBaseFinalizeFunc) NULL,
+	  (GClassInitFunc) gtk_tool_button_class_init,
+	  (GClassFinalizeFunc) NULL,
+	  NULL,
+	  sizeof (GtkToolButton),
+	  0, /* n_preallocs */
+	  (GInstanceInitFunc) gtk_tool_button_init,
+	};
 
-      type = g_type_register_static_simple (GTK_TYPE_TOOL_ITEM,
-					    I_("GtkToolButton"),
-					    sizeof (GtkToolButtonClass),
-					    (GClassInitFunc) gtk_tool_button_class_init,
-					    sizeof (GtkToolButton),
-					    (GInstanceInitFunc) gtk_tool_button_init,
-					    0);
-
-      g_type_add_interface_static (type, GTK_TYPE_ACTIVATABLE,
-                                   &activatable_info);
+      type = g_type_register_static (GTK_TYPE_TOOL_ITEM,
+				     "GtkToolButton",
+				     &type_info, 0);
     }
   return type;
 }
@@ -155,8 +136,6 @@ gtk_tool_button_class_init (GtkToolButtonClass *klass)
   object_class->notify = gtk_tool_button_property_notify;
   object_class->finalize = gtk_tool_button_finalize;
 
-  widget_class->style_set = gtk_tool_button_style_set;
-
   tool_item_class->create_menu_proxy = gtk_tool_button_create_menu_proxy;
   tool_item_class->toolbar_reconfigured = gtk_tool_button_toolbar_reconfigured;
   
@@ -167,17 +146,14 @@ gtk_tool_button_class_init (GtkToolButtonClass *klass)
    *          - if the tool button has an icon_widget, then that widget
    *            will be used as the icon. Otherwise, if the tool button
    *            has a stock id, the corresponding stock icon will be
-   *            used. Otherwise, if the tool button has an icon name,
-   *            the corresponding icon from the theme will be used.
-   *            Otherwise, the tool button will not have an icon.
+   *            used. Otherwise, the tool button will not have an icon.
    *
    *          - if the tool button has a label_widget then that widget
    *            will be used as the label. Otherwise, if the tool button
    *            has a label text, that text will be used as label. Otherwise,
    *            if the toolbutton has a stock id, the corresponding text
-   *            will be used as label. Otherwise, if the tool button has
-   *            an icon name, the corresponding icon name from the theme will
-   *            be used. Otherwise, the toolbutton will have an empty label.
+   *            will be used as label. Otherwise, the toolbutton will
+   *            have an empty label.
    *
    *	      - The use_underline property only has an effect when the label
    *            on the toolbutton comes from the label property (ie. not from
@@ -204,68 +180,35 @@ gtk_tool_button_class_init (GtkToolButtonClass *klass)
 							P_("Label"),
 							P_("Text to show in the item."),
 							NULL,
-							GTK_PARAM_READWRITE));
+							G_PARAM_READWRITE));
   g_object_class_install_property (object_class,
 				   PROP_USE_UNDERLINE,
-				   g_param_spec_boolean ("use-underline",
+				   g_param_spec_boolean ("use_underline",
 							 P_("Use underline"),
 							 P_("If set, an underline in the label property indicates that the next character should be used for the mnemonic accelerator key in the overflow menu"),
 							 FALSE,
-							 GTK_PARAM_READWRITE));
+							 G_PARAM_READWRITE));
   g_object_class_install_property (object_class,
 				   PROP_LABEL_WIDGET,
-				   g_param_spec_object ("label-widget",
+				   g_param_spec_object ("label_widget",
 							P_("Label widget"),
 							P_("Widget to use as the item label"),
 							GTK_TYPE_WIDGET,
-							GTK_PARAM_READWRITE));
+							G_PARAM_READWRITE));
   g_object_class_install_property (object_class,
 				   PROP_STOCK_ID,
-				   g_param_spec_string ("stock-id",
+				   g_param_spec_string ("stock_id",
 							P_("Stock Id"),
 							P_("The stock icon displayed on the item"),
 							NULL,
-							GTK_PARAM_READWRITE));
-
-  /**
-   * GtkToolButton:icon-name:
-   * 
-   * The name of the themed icon displayed on the item.
-   * This property only has an effect if not overridden by "label", 
-   * "icon_widget" or "stock_id" properties.
-   *
-   * Since: 2.8 
-   */
-  g_object_class_install_property (object_class,
-				   PROP_ICON_NAME,
-				   g_param_spec_string ("icon-name",
-							P_("Icon name"),
-							P_("The name of the themed icon displayed on the item"),
-							NULL,
-							GTK_PARAM_READWRITE));
+							G_PARAM_READWRITE));
   g_object_class_install_property (object_class,
 				   PROP_ICON_WIDGET,
-				   g_param_spec_object ("icon-widget",
+				   g_param_spec_object ("icon_widget",
 							P_("Icon widget"),
 							P_("Icon widget to display in the item"),
 							GTK_TYPE_WIDGET,
-							GTK_PARAM_READWRITE));
-
-  /**
-   * GtkButton:icon-spacing:
-   * 
-   * Spacing in pixels between the icon and label.
-   * 
-   * Since: 2.10
-   */
-  gtk_widget_class_install_style_property (widget_class,
-					   g_param_spec_int ("icon-spacing",
-							     P_("Icon spacing"),
-							     P_("Spacing in pixels between the icon and label"),
-							     0,
-							     G_MAXINT,
-							     3,
-							     GTK_PARAM_READWRITE));
+							G_PARAM_READWRITE));
 
 /**
  * GtkToolButton::clicked:
@@ -275,9 +218,9 @@ gtk_tool_button_class_init (GtkToolButtonClass *klass)
  * or activated with the keyboard.
  **/
   toolbutton_signals[CLICKED] =
-    g_signal_new (I_("clicked"),
+    g_signal_new ("clicked",
 		  G_OBJECT_CLASS_TYPE (klass),
-		  G_SIGNAL_RUN_FIRST | G_SIGNAL_ACTION,
+		  G_SIGNAL_RUN_FIRST,
 		  G_STRUCT_OFFSET (GtkToolButtonClass, clicked),
 		  NULL, NULL,
 		  g_cclosure_marshal_VOID__VOID,
@@ -294,8 +237,6 @@ gtk_tool_button_init (GtkToolButton      *button,
   
   button->priv = GTK_TOOL_BUTTON_GET_PRIVATE (button);
 
-  button->priv->contents_invalid = TRUE;
-
   gtk_tool_item_set_homogeneous (toolitem, TRUE);
 
   /* create button */
@@ -319,16 +260,15 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
   gboolean need_icon = FALSE;
   GtkIconSize icon_size;
   GtkWidget *box = NULL;
-  guint icon_spacing;
-  GtkOrientation text_orientation = GTK_ORIENTATION_HORIZONTAL;
-  GtkSizeGroup *size_group = NULL;
-
-  button->priv->contents_invalid = FALSE;
-
-  gtk_widget_style_get (GTK_WIDGET (tool_item), 
-			"icon-spacing", &icon_spacing,
-			NULL);
 
+  if (gtk_tool_item_get_proxy_menu_item (tool_item, MENU_ID))
+    {
+      /* Remove item, so it will be recreated on the next
+       * create_proxy_menu_item()
+       */
+      gtk_tool_item_set_proxy_menu_item (tool_item, MENU_ID, NULL);
+    }
+  
   if (button->priv->icon_widget && button->priv->icon_widget->parent)
     {
       gtk_container_remove (GTK_CONTAINER (button->priv->icon_widget->parent),
@@ -359,28 +299,16 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
 
   if (style == GTK_TOOLBAR_BOTH_HORIZ &&
       (gtk_tool_item_get_is_important (GTK_TOOL_ITEM (button)) ||
-       gtk_tool_item_get_orientation (GTK_TOOL_ITEM (button)) == GTK_ORIENTATION_VERTICAL ||
-       gtk_tool_item_get_text_orientation (GTK_TOOL_ITEM (button)) == GTK_ORIENTATION_VERTICAL))
+       gtk_tool_item_get_orientation (GTK_TOOL_ITEM (button)) == GTK_ORIENTATION_VERTICAL))
     {
       need_label = TRUE;
     }
   
-  if (style == GTK_TOOLBAR_ICONS && button->priv->icon_widget == NULL &&
-      button->priv->stock_id == NULL && button->priv->icon_name == NULL)
-    {
-      need_label = TRUE;
-      need_icon = FALSE;
-      style = GTK_TOOLBAR_TEXT;
-    }
-
-  if (style == GTK_TOOLBAR_TEXT && button->priv->label_widget == NULL &&
-      button->priv->stock_id == NULL && button->priv->label_text == NULL)
-    {
-      need_label = FALSE;
-      need_icon = TRUE;
-      style = GTK_TOOLBAR_ICONS;
-    }
-
+  if (style != GTK_TOOLBAR_ICONS &&
+      ((style != GTK_TOOLBAR_BOTH_HORIZ ||
+	gtk_tool_item_get_is_important (GTK_TOOL_ITEM (button)))))
+    need_label = TRUE;
+  
   if (need_label)
     {
       if (button->priv->label_widget)
@@ -420,28 +348,6 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
 	  
 	  gtk_widget_show (label);
 	}
-
-      gtk_label_set_ellipsize (GTK_LABEL (label),
-			       gtk_tool_item_get_ellipsize_mode (GTK_TOOL_ITEM (button)));
-      text_orientation = gtk_tool_item_get_text_orientation (GTK_TOOL_ITEM (button));
-      if (text_orientation == GTK_ORIENTATION_HORIZONTAL)
-	{
-          gtk_label_set_angle (GTK_LABEL (label), 0);
-          gtk_misc_set_alignment (GTK_MISC (label),
-                                  gtk_tool_item_get_text_alignment (GTK_TOOL_ITEM (button)),
-                                  0.5);
-        }
-      else
-        {
-          gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_NONE);
-	  if (gtk_widget_get_direction (GTK_WIDGET (tool_item)) == GTK_TEXT_DIR_RTL)
-	    gtk_label_set_angle (GTK_LABEL (label), -90);
-	  else
-	    gtk_label_set_angle (GTK_LABEL (label), 90);
-          gtk_misc_set_alignment (GTK_MISC (label),
-                                  0.5,
-                                  1 - gtk_tool_item_get_text_alignment (GTK_TOOL_ITEM (button)));
-        }
     }
 
   icon_size = gtk_tool_item_get_icon_size (GTK_TOOL_ITEM (button));
@@ -453,38 +359,16 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
 	  
 	  if (GTK_IS_IMAGE (icon))
 	    {
-	      g_object_set (button->priv->icon_widget,
+	      g_object_set (G_OBJECT (button->priv->icon_widget),
 			    "icon-size", icon_size,
 			    NULL);
 	    }
 	}
-      else if (button->priv->stock_id && 
-	       gtk_icon_factory_lookup_default (button->priv->stock_id))
+      else if (button->priv->stock_id)
 	{
 	  icon = gtk_image_new_from_stock (button->priv->stock_id, icon_size);
 	  gtk_widget_show (icon);
 	}
-      else if (button->priv->icon_name)
-	{
-	  icon = gtk_image_new_from_icon_name (button->priv->icon_name, icon_size);
-	  gtk_widget_show (icon);
-	}
-
-      if (icon && text_orientation == GTK_ORIENTATION_HORIZONTAL)
-	gtk_misc_set_alignment (GTK_MISC (icon),
-				1.0 - gtk_tool_item_get_text_alignment (GTK_TOOL_ITEM (button)),
-				0.5);
-      else if (icon)
-	gtk_misc_set_alignment (GTK_MISC (icon),
-				0.5,
-				gtk_tool_item_get_text_alignment (GTK_TOOL_ITEM (button)));
-
-      if (icon)
-	{
-	  size_group = gtk_tool_item_get_text_size_group (GTK_TOOL_ITEM (button));
-	  if (size_group != NULL)
-	    gtk_size_group_add_widget (size_group, icon);
-	}
     }
 
   switch (style)
@@ -495,33 +379,19 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
       break;
 
     case GTK_TOOLBAR_BOTH:
-      if (text_orientation == GTK_ORIENTATION_HORIZONTAL)
-	box = gtk_vbox_new (FALSE, icon_spacing);
-      else
-	box = gtk_hbox_new (FALSE, icon_spacing);
+      box = gtk_vbox_new (FALSE, 0);
       if (icon)
 	gtk_box_pack_start (GTK_BOX (box), icon, TRUE, TRUE, 0);
-      gtk_box_pack_end (GTK_BOX (box), label, FALSE, TRUE, 0);
+      gtk_box_pack_start (GTK_BOX (box), label, FALSE, TRUE, 0);
       gtk_container_add (GTK_CONTAINER (button->priv->button), box);
       break;
 
     case GTK_TOOLBAR_BOTH_HORIZ:
-      if (text_orientation == GTK_ORIENTATION_HORIZONTAL)
-	{
-	  box = gtk_hbox_new (FALSE, icon_spacing);
-	  if (icon)
-	    gtk_box_pack_start (GTK_BOX (box), icon, label? FALSE : TRUE, TRUE, 0);
-	  if (label)
-	    gtk_box_pack_end (GTK_BOX (box), label, TRUE, TRUE, 0);
-	}
-      else
-	{
-	  box = gtk_vbox_new (FALSE, icon_spacing);
-	  if (icon)
-	    gtk_box_pack_end (GTK_BOX (box), icon, label ? FALSE : TRUE, TRUE, 0);
-	  if (label)
-	    gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
-	}
+      box = gtk_hbox_new (FALSE, 0);
+      if (icon)
+	gtk_box_pack_start (GTK_BOX (box), icon, label? FALSE : TRUE, TRUE, 0);
+      if (label)
+	gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
       gtk_container_add (GTK_CONTAINER (button->priv->button), box);
       break;
 
@@ -536,8 +406,6 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
   gtk_button_set_relief (GTK_BUTTON (button->priv->button),
 			 gtk_tool_item_get_relief_style (GTK_TOOL_ITEM (button)));
 
-  gtk_tool_item_rebuild_menu (tool_item);
-  
   gtk_widget_queue_resize (GTK_WIDGET (button));
 }
 
@@ -563,15 +431,11 @@ gtk_tool_button_set_property (GObject         *object,
     case PROP_STOCK_ID:
       gtk_tool_button_set_stock_id (button, g_value_get_string (value));
       break;
-    case PROP_ICON_NAME:
-      gtk_tool_button_set_icon_name (button, g_value_get_string (value));
-      break;
     case PROP_ICON_WIDGET:
       gtk_tool_button_set_icon_widget (button, g_value_get_object (value));
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-      break;
     }
 }
 
@@ -579,10 +443,7 @@ static void
 gtk_tool_button_property_notify (GObject          *object,
 				 GParamSpec       *pspec)
 {
-  GtkToolButton *button = GTK_TOOL_BUTTON (object);
-
-  if (button->priv->contents_invalid ||
-      strcmp ("is-important", pspec->name) == 0)
+  if (strcmp (pspec->name, "is-important") == 0)
     gtk_tool_button_construct_contents (GTK_TOOL_ITEM (object));
 
   if (parent_class->notify)
@@ -611,15 +472,11 @@ gtk_tool_button_get_property (GObject         *object,
     case PROP_STOCK_ID:
       g_value_set_string (value, button->priv->stock_id);
       break;
-    case PROP_ICON_NAME:
-      g_value_set_string (value, button->priv->icon_name);
-      break;
     case PROP_ICON_WIDGET:
       g_value_set_object (value, button->priv->icon_widget);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-      break;
     }
 }
 
@@ -628,15 +485,17 @@ gtk_tool_button_finalize (GObject *object)
 {
   GtkToolButton *button = GTK_TOOL_BUTTON (object);
 
-  g_free (button->priv->stock_id);
-  g_free (button->priv->icon_name);
-  g_free (button->priv->label_text);
+  if (button->priv->stock_id)
+    g_free (button->priv->stock_id);
+
+  if (button->priv->label_text)
+    g_free (button->priv->label_text);
 
   if (button->priv->label_widget)
-    g_object_unref (button->priv->label_widget);
+    g_object_unref (G_OBJECT (button->priv->label_widget));
 
   if (button->priv->icon_widget)
-    g_object_unref (button->priv->icon_widget);
+    g_object_unref (G_OBJECT (button->priv->icon_widget));
   
   parent_class->finalize (object);
 }
@@ -652,24 +511,12 @@ clone_image_menu_size (GtkImage *image, GtkSettings *settings)
       gtk_image_get_stock (image, &stock_id, NULL);
       return gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_MENU);
     }
-  else if (storage_type == GTK_IMAGE_ICON_NAME)
-    {
-      const gchar *icon_name;
-      gtk_image_get_icon_name (image, &icon_name, NULL);
-      return gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
-    }
   else if (storage_type == GTK_IMAGE_ICON_SET)
     {
       GtkIconSet *icon_set;
       gtk_image_get_icon_set (image, &icon_set, NULL);
       return gtk_image_new_from_icon_set (icon_set, GTK_ICON_SIZE_MENU);
     }
-  else if (storage_type == GTK_IMAGE_GICON)
-    {
-      GIcon *icon;
-      gtk_image_get_gicon (image, &icon, NULL);
-      return gtk_image_new_from_gicon (icon, GTK_ICON_SIZE_MENU);
-    }
   else if (storage_type == GTK_IMAGE_PIXBUF)
     {
       gint width, height;
@@ -679,16 +526,12 @@ clone_image_menu_size (GtkImage *image, GtkSettings *settings)
 					     &width, &height))
 	{
 	  GdkPixbuf *src_pixbuf, *dest_pixbuf;
-	  GtkWidget *cloned_image;
 
 	  src_pixbuf = gtk_image_get_pixbuf (image);
 	  dest_pixbuf = gdk_pixbuf_scale_simple (src_pixbuf, width, height,
 						 GDK_INTERP_BILINEAR);
 
-	  cloned_image = gtk_image_new_from_pixbuf (dest_pixbuf);
-	  g_object_unref (dest_pixbuf);
-
-	  return cloned_image;
+	  return gtk_image_new_from_pixbuf (dest_pixbuf);
 	}
     }
 
@@ -705,10 +548,7 @@ gtk_tool_button_create_menu_proxy (GtkToolItem *item)
   gboolean use_mnemonic = TRUE;
   const char *label;
 
-  if (_gtk_tool_item_create_menu_proxy (item))
-    return TRUE;
- 
-  if (GTK_IS_LABEL (button->priv->label_widget))
+  if (button->priv->label_widget && GTK_IS_LABEL (button->priv->label_widget))
     {
       label = gtk_label_get_label (GTK_LABEL (button->priv->label_widget));
       use_mnemonic = gtk_label_get_use_underline (GTK_LABEL (button->priv->label_widget));
@@ -732,7 +572,7 @@ gtk_tool_button_create_menu_proxy (GtkToolItem *item)
   else
     menu_item = gtk_image_menu_item_new_with_label (label);
 
-  if (GTK_IS_IMAGE (button->priv->icon_widget))
+  if (button->priv->icon_widget && GTK_IS_IMAGE (button->priv->icon_widget))
     {
       menu_image = clone_image_menu_size (GTK_IMAGE (button->priv->icon_widget),
 					  gtk_widget_get_settings (GTK_WIDGET (button)));
@@ -760,13 +600,6 @@ static void
 button_clicked (GtkWidget     *widget,
 		GtkToolButton *button)
 {
-  GtkAction *action;
-
-  action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (button));
-  
-  if (action)
-    gtk_action_activate (action);
-
   g_signal_emit_by_name (button, "clicked");
 }
 
@@ -776,127 +609,6 @@ gtk_tool_button_toolbar_reconfigured (GtkToolItem *tool_item)
   gtk_tool_button_construct_contents (tool_item);
 }
 
-static void 
-gtk_tool_button_update_icon_spacing (GtkToolButton *button)
-{
-  GtkWidget *box;
-  guint spacing;
-
-  box = GTK_BIN (button->priv->button)->child;
-  if (GTK_IS_BOX (box))
-    {
-      gtk_widget_style_get (GTK_WIDGET (button), 
-			    "icon-spacing", &spacing,
-			    NULL);
-      gtk_box_set_spacing (GTK_BOX (box), spacing);      
-    }
-}
-
-static void
-gtk_tool_button_style_set (GtkWidget *widget,
-			   GtkStyle  *prev_style)
-{
-  gtk_tool_button_update_icon_spacing (GTK_TOOL_BUTTON (widget));
-}
-
-static void 
-gtk_tool_button_activatable_interface_init (GtkActivatableIface  *iface)
-{
-  parent_activatable_iface = g_type_interface_peek_parent (iface);
-  iface->update = gtk_tool_button_update;
-  iface->sync_action_properties = gtk_tool_button_sync_action_properties;
-}
-
-static void
-gtk_tool_button_update (GtkActivatable *activatable,
-			GtkAction      *action,
-			const gchar    *property_name)
-{
-  GtkToolButton *button;
-  GtkWidget *image;
-
-  parent_activatable_iface->update (activatable, action, property_name);
-
-  if (!gtk_activatable_get_use_action_appearance (activatable))
-    return;
-
-  button = GTK_TOOL_BUTTON (activatable);
-  
-  if (strcmp (property_name, "short-label") == 0)
-    gtk_tool_button_set_label (button, gtk_action_get_short_label (action));
-  else if (strcmp (property_name, "stock-id") == 0)
-    gtk_tool_button_set_stock_id (button, gtk_action_get_stock_id (action));
-  else if (strcmp (property_name, "gicon") == 0)
-    {
-      const gchar *stock_id = gtk_action_get_stock_id (action);
-      GIcon *icon = gtk_action_get_gicon (action);
-      GtkIconSize icon_size = GTK_ICON_SIZE_BUTTON;
-
-      if ((stock_id && gtk_icon_factory_lookup_default (stock_id)) || !icon)
-	image = NULL;
-      else 
-	{   
-	  image = gtk_tool_button_get_icon_widget (button);
-	  icon_size = gtk_tool_item_get_icon_size (GTK_TOOL_ITEM (button));
-
-	  if (!image)
-	    image = gtk_image_new ();
-	}
-
-      gtk_tool_button_set_icon_widget (button, image);
-      gtk_image_set_from_gicon (GTK_IMAGE (image), icon, icon_size);
-
-    }
-  else if (strcmp (property_name, "icon-name") == 0)
-    gtk_tool_button_set_icon_name (button, gtk_action_get_icon_name (action));
-}
-
-static void
-gtk_tool_button_sync_action_properties (GtkActivatable *activatable,
-				        GtkAction      *action)
-{
-  GtkToolButton *button;
-  GIcon         *icon;
-  const gchar   *stock_id;
-
-  parent_activatable_iface->sync_action_properties (activatable, action);
-
-  if (!action)
-    return;
-
-  if (!gtk_activatable_get_use_action_appearance (activatable))
-    return;
-
-  button = GTK_TOOL_BUTTON (activatable);
-  stock_id = gtk_action_get_stock_id (action);
-
-  gtk_tool_button_set_label (button, gtk_action_get_short_label (action));
-  gtk_tool_button_set_use_underline (button, TRUE);
-  gtk_tool_button_set_stock_id (button, stock_id);
-  gtk_tool_button_set_icon_name (button, gtk_action_get_icon_name (action));
-
-  if (stock_id && gtk_icon_factory_lookup_default (stock_id))
-      gtk_tool_button_set_icon_widget (button, NULL);
-  else if ((icon = gtk_action_get_gicon (action)) != NULL)
-    {
-      GtkIconSize icon_size = gtk_tool_item_get_icon_size (GTK_TOOL_ITEM (button));
-      GtkWidget  *image = gtk_tool_button_get_icon_widget (button);
-      
-      if (!image)
-	{
-	  image = gtk_image_new ();
-	  gtk_widget_show (image);
-	  gtk_tool_button_set_icon_widget (button, image);
-	}
-
-      gtk_image_set_from_gicon (GTK_IMAGE (image), icon, icon_size);
-    }
-  else if (gtk_action_get_icon_name (action))
-    gtk_tool_button_set_icon_name (button, gtk_action_get_icon_name (action));
-  else
-    gtk_tool_button_set_label (button, gtk_action_get_short_label (action));
-}
-
 /**
  * gtk_tool_button_new_from_stock:
  * @stock_id: the name of the stock item 
@@ -919,7 +631,7 @@ gtk_tool_button_new_from_stock (const gchar *stock_id)
   g_return_val_if_fail (stock_id != NULL, NULL);
     
   button = g_object_new (GTK_TYPE_TOOL_BUTTON,
-			 "stock-id", stock_id,
+			 "stock_id", stock_id,
 			 NULL);
 
   return GTK_TOOL_ITEM (button);
@@ -927,12 +639,12 @@ gtk_tool_button_new_from_stock (const gchar *stock_id)
 
 /**
  * gtk_tool_button_new:
- * @label: (allow-none): a string that will be used as label, or %NULL
- * @icon_widget: (allow-none): a #GtkMisc widget that will be used as icon widget, or %NULL
- *
+ * @label: a string that will be used as label, or %NULL
+ * @icon_widget: a widget that will be used as icon widget, or %NULL
+ * 
  * Creates a new %GtkToolButton using @icon_widget as icon and @label as
  * label.
- *
+ * 
  * Return value: A new #GtkToolButton
  * 
  * Since: 2.4
@@ -943,12 +655,14 @@ gtk_tool_button_new (GtkWidget	 *icon_widget,
 {
   GtkToolButton *button;
 
-  g_return_val_if_fail (icon_widget == NULL || GTK_IS_MISC (icon_widget), NULL);
-
   button = g_object_new (GTK_TYPE_TOOL_BUTTON,
-                         "label", label,
-                         "icon-widget", icon_widget,
 			 NULL);
+  
+  if (label)
+    gtk_tool_button_set_label (button, label);
+
+  if (icon_widget)
+    gtk_tool_button_set_icon_widget (button, icon_widget);
 
   return GTK_TOOL_ITEM (button);  
 }
@@ -956,8 +670,8 @@ gtk_tool_button_new (GtkWidget	 *icon_widget,
 /**
  * gtk_tool_button_set_label:
  * @button: a #GtkToolButton
- * @label: (allow-none): a string that will be used as label, or %NULL.
- *
+ * @label: a string that will be used as label, or %NULL.
+ * 
  * Sets @label as the label used for the tool button. The "label" property
  * only has an effect if not overridden by a non-%NULL "label_widget" property.
  * If both the "label_widget" and "label" properties are %NULL, the label
@@ -971,27 +685,18 @@ gtk_tool_button_set_label (GtkToolButton *button,
 			   const gchar   *label)
 {
   gchar *old_label;
-  gchar *elided_label;
-  AtkObject *accessible;
   
   g_return_if_fail (GTK_IS_TOOL_BUTTON (button));
 
   old_label = button->priv->label_text;
 
   button->priv->label_text = g_strdup (label);
-  button->priv->contents_invalid = TRUE;     
-
-  if (label)
-    {
-      elided_label = _gtk_toolbar_elide_underscores (label);
-      accessible = gtk_widget_get_accessible (GTK_WIDGET (button->priv->button));
-      atk_object_set_name (accessible, elided_label);
-      g_free (elided_label);
-    }
-
-  g_free (old_label);
- 
+  gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
+      
   g_object_notify (G_OBJECT (button), "label");
+
+  if (old_label)
+    g_free (old_label);
 }
 
 /**
@@ -1041,9 +746,10 @@ gtk_tool_button_set_use_underline (GtkToolButton *button,
   if (use_underline != button->priv->use_underline)
     {
       button->priv->use_underline = use_underline;
-      button->priv->contents_invalid = TRUE;
 
-      g_object_notify (G_OBJECT (button), "use-underline");
+      gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
+
+      g_object_notify (G_OBJECT (button), "use_underline");
     }
 }
 
@@ -1070,8 +776,8 @@ gtk_tool_button_get_use_underline (GtkToolButton *button)
 /**
  * gtk_tool_button_set_stock_id:
  * @button: a #GtkToolButton
- * @stock_id: (allow-none): a name of a stock item, or %NULL
- *
+ * @stock_id: a name of a stock item, or %NULL
+ * 
  * Sets the name of the stock item. See gtk_tool_button_new_from_stock().
  * The stock_id property only has an effect if not
  * overridden by non-%NULL "label" and "icon_widget" properties.
@@ -1089,11 +795,11 @@ gtk_tool_button_set_stock_id (GtkToolButton *button,
   old_stock_id = button->priv->stock_id;
 
   button->priv->stock_id = g_strdup (stock_id);
-  button->priv->contents_invalid = TRUE;
+  gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
+  
+  g_object_notify (G_OBJECT (button), "stock_id");
 
   g_free (old_stock_id);
-  
-  g_object_notify (G_OBJECT (button), "stock-id");
 }
 
 /**
@@ -1115,62 +821,11 @@ gtk_tool_button_get_stock_id (GtkToolButton *button)
   return button->priv->stock_id;
 }
 
-/**
- * gtk_tool_button_set_icon_name
- * @button: a #GtkToolButton
- * @icon_name: (allow-none): the name of the themed icon
- *
- * Sets the icon for the tool button from a named themed icon.
- * See the docs for #GtkIconTheme for more details.
- * The "icon_name" property only has an effect if not
- * overridden by non-%NULL "label", "icon_widget" and "stock_id"
- * properties.
- * 
- * Since: 2.8
- **/
-void
-gtk_tool_button_set_icon_name (GtkToolButton *button,
-			       const gchar   *icon_name)
-{
-  gchar *old_icon_name;
-
-  g_return_if_fail (GTK_IS_TOOL_BUTTON (button));
-
-  old_icon_name = button->priv->icon_name;
-
-  button->priv->icon_name = g_strdup (icon_name);
-  button->priv->contents_invalid = TRUE; 
-
-  g_free (old_icon_name);
-
-  g_object_notify (G_OBJECT (button), "icon-name");
-}
-
-/**
- * gtk_tool_button_get_icon_name
- * @button: a #GtkToolButton
- * 
- * Returns the name of the themed icon for the tool button,
- * see gtk_tool_button_set_icon_name().
- *
- * Returns: the icon name or %NULL if the tool button has
- * no themed icon
- * 
- * Since: 2.8
- **/
-G_CONST_RETURN gchar*
-gtk_tool_button_get_icon_name (GtkToolButton *button)
-{
-  g_return_val_if_fail (GTK_IS_TOOL_BUTTON (button), NULL);
-
-  return button->priv->icon_name;
-}
-
 /**
  * gtk_tool_button_set_icon_widget:
  * @button: a #GtkToolButton
- * @icon_widget: (allow-none): the widget used as icon, or %NULL
- *
+ * @icon_widget: the widget used as icon, or %NULL
+ * 
  * Sets @icon as the widget used as icon on @button. If @icon_widget is
  * %NULL the icon is determined by the "stock_id" property. If the
  * "stock_id" property is also %NULL, @button will not have an icon.
@@ -1187,29 +842,27 @@ gtk_tool_button_set_icon_widget (GtkToolButton *button,
   if (icon_widget != button->priv->icon_widget)
     {
       if (button->priv->icon_widget)
-	{
-	  if (button->priv->icon_widget->parent)
-	    gtk_container_remove (GTK_CONTAINER (button->priv->icon_widget->parent),
-				    button->priv->icon_widget);
+	g_object_unref (G_OBJECT (button->priv->icon_widget));
 
-	  g_object_unref (button->priv->icon_widget);
-	}
-      
       if (icon_widget)
-	g_object_ref_sink (icon_widget);
+	{
+	  g_object_ref (icon_widget);
+	  gtk_object_sink (GTK_OBJECT (icon_widget));
+	}
 
       button->priv->icon_widget = icon_widget;
-      button->priv->contents_invalid = TRUE;
+
+      gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
       
-      g_object_notify (G_OBJECT (button), "icon-widget");
+      g_object_notify (G_OBJECT (button), "icon_widget");
     }
 }
 
 /**
  * gtk_tool_button_set_label_widget:
  * @button: a #GtkToolButton
- * @label_widget: (allow-none): the widget used as label, or %NULL
- *
+ * @label_widget: the widget used as label, or %NULL
+ * 
  * Sets @label_widget as the widget that will be used as the label
  * for @button. If @label_widget is %NULL the "label" property is used
  * as label. If "label" is also %NULL, the label in the stock item
@@ -1228,21 +881,19 @@ gtk_tool_button_set_label_widget (GtkToolButton *button,
   if (label_widget != button->priv->label_widget)
     {
       if (button->priv->label_widget)
-	{
-	  if (button->priv->label_widget->parent)
-	    gtk_container_remove (GTK_CONTAINER (button->priv->label_widget->parent),
-		    	          button->priv->label_widget);
-	  
-	  g_object_unref (button->priv->label_widget);
-	}
-      
+	g_object_unref (button->priv->label_widget);
+
       if (label_widget)
-	g_object_ref_sink (label_widget);
+	{
+	  g_object_ref (label_widget);
+	  gtk_object_sink (GTK_OBJECT (label_widget));
+	}
 
       button->priv->label_widget = label_widget;
-      button->priv->contents_invalid = TRUE;
+
+      gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
       
-      g_object_notify (G_OBJECT (button), "label-widget");
+      g_object_notify (G_OBJECT (button), "label_widget");
     }
 }
 
@@ -1292,6 +943,3 @@ _gtk_tool_button_get_button (GtkToolButton *button)
   return button->priv->button;
 }
 
-
-#define __GTK_TOOL_BUTTON_C__
-#include "gtkaliasdef.c"
