@@ -1,4 +1,4 @@
-#include "config.h"
+#include <config.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -34,6 +34,27 @@ dump_accels (void)
   gtk_accel_map_save_fd (STDOUT_FILENO);
 }
 
+static void
+print_toplevel (GtkWidget *widget, gpointer user_data)
+{
+  g_print ("%s\n", G_OBJECT_TYPE_NAME (widget));
+}
+
+static void
+dump_toplevels (GtkWidget    *button, 
+		GtkUIManager *merge)
+{
+  GSList *toplevels;
+
+  toplevels = gtk_ui_manager_get_toplevels (merge, 
+					    GTK_UI_MANAGER_MENUBAR |
+					    GTK_UI_MANAGER_TOOLBAR |
+					    GTK_UI_MANAGER_POPUP);
+
+  g_slist_foreach (toplevels, (GFunc)print_toplevel, NULL);
+  g_slist_free (toplevels);
+}
+
 static void
 toggle_tearoffs (GtkWidget    *button, 
 		 GtkUIManager *merge)
@@ -138,7 +159,7 @@ static GtkActionEntry entries[] = {
   { "QuitAction",  GTK_STOCK_QUIT,  NULL,     "<control>q", "Quit", G_CALLBACK (gtk_main_quit) },
   { "NewAction",   GTK_STOCK_NEW,   NULL,     "<control>n", "Create something", G_CALLBACK (activate_action) },
   { "New2Action",  GTK_STOCK_NEW,   NULL,     "<control>m", "Create something else", G_CALLBACK (activate_action) },
-  { "OpenAction",  GTK_STOCK_OPEN,  NULL,     "<control>o", "Open it", G_CALLBACK (activate_action) },
+  { "OpenAction",  GTK_STOCK_OPEN,  NULL,     NULL,         "Open it", G_CALLBACK (activate_action) },
   { "CutAction",   GTK_STOCK_CUT,   NULL,     "<control>x", "Knive", G_CALLBACK (activate_action) },
   { "CopyAction",  GTK_STOCK_COPY,  NULL,     "<control>c", "Copy", G_CALLBACK (activate_action) },
   { "PasteAction", GTK_STOCK_PASTE, NULL,     "<control>v", "Paste", G_CALLBACK (activate_action) },
@@ -501,7 +522,8 @@ unset_tip (GtkWidget *widget)
 }
 		    
 static void
-connect_proxy (GtkAction    *action,
+connect_proxy (GtkUIManager *merge,
+	       GtkAction    *action,
 	       GtkWidget    *proxy,
 	       GtkWidget    *statusbar)
 {
@@ -539,7 +561,6 @@ main (int argc, char **argv)
 {
   GtkActionGroup *action_group;
   GtkAction *action;
-  GList *tmp;
   GtkUIManager *merge;
   GtkWidget *window, *table, *frame, *menu_box, *vbox, *view;
   GtkWidget *button, *area, *statusbar;
@@ -602,15 +623,9 @@ main (int argc, char **argv)
 			    button);
   gtk_widget_show (button);
 
-  for (tmp = gtk_action_group_list_actions (action_group);
-       tmp != NULL;
-       tmp = tmp->next)
-    {
-      action = tmp->data;
-      g_signal_connect (action, "connect-proxy", 
-			G_CALLBACK (connect_proxy), statusbar);
-    }
   merge = gtk_ui_manager_new ();
+
+  g_signal_connect (merge, "connect-proxy", G_CALLBACK (connect_proxy), statusbar);
   g_signal_connect (area, "button_press_event", G_CALLBACK (area_press), merge);
 
   gtk_ui_manager_insert_action_group (merge, action_group, 0);
@@ -652,6 +667,10 @@ main (int argc, char **argv)
   g_signal_connect (button, "clicked", G_CALLBACK (dump_tree), merge);
   gtk_box_pack_end (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 
+  button = gtk_button_new_with_label ("Dump Toplevels");
+  g_signal_connect (button, "clicked", G_CALLBACK (dump_toplevels), merge);
+  gtk_box_pack_end (GTK_BOX (vbox), button, FALSE, FALSE, 0);
+
   button = gtk_button_new_with_label ("Dump Accels");
   g_signal_connect (button, "clicked", G_CALLBACK (dump_accels), NULL);
   gtk_box_pack_end (GTK_BOX (vbox), button, FALSE, FALSE, 0);
